@@ -2,16 +2,17 @@ from .unibit import UniBit as ub
 
 class StockNews(ub):
 
-	def getLatestStockNews(self, ticker):
+	def getLatestStockNews(self, ticker, datatype='json'):
 		""" Get latest stock news by ticker
 
 		Keyword Arguments:
 			ticker: Company ticker 
+			datatype: Data type of response. Either 'json' or 'csv' 
 		"""
 
 		endpoints = ['news', 'latest']
 
-		return self.make_request(ticker=ticker, endpoints=endpoints, data={})
+		return self.make_request(ticker=ticker, endpoints=endpoints, data={'datatype':datatype})
 
 	def getStockNewsAnalysis(self, ticker, interval):
 		""" Get analyzed stock news, including tags, sentiment, and named entities
